package com.delfines.spring.controller;

import java.util.LinkedList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.delfines.Constante;
import com.delfines.business.ClienteBo;
import com.delfines.business.RegistroFacturaBo;
import com.delfines.business.ServicioBo;
import com.delfines.vo.Cliente;
import com.delfines.vo.Comprobante;
import com.delfines.vo.ComprobanteDetalle;
import com.delfines.vo.DbfGeneracion;
import com.delfines.vo.Servicio;
import com.delfines.vo.Usuario;
import com.delfines.vo.Value;

/**
 * @author imssbora
 */
@Controller
public class ClienteController {
   
   @RequestMapping(path={"/lista-cliente"},method=RequestMethod.GET)
   public ModelAndView listaServicios(Model model,HttpServletRequest request) {
	    ClienteBo servicio=new ClienteBo();
	    
	    List lista=servicio.listaClientes();
	    
		ModelAndView mv = new ModelAndView("mante-cliente-tabla");
		mv.addObject("lista",lista);
		return mv;
   }
   
   @RequestMapping(path={"/registro-cliente"},method=RequestMethod.GET)
   public ModelAndView registroServicio(Integer idCliente,Integer idTipoCliente,Integer idTipoDocumento,String denominacion,
		   String nrodocumento,String telefono,String direccion,Model model,HttpServletRequest request) {
	    
	    Integer res=Constante.ID_INICIAL; 
	    ClienteBo servicio=new ClienteBo();
	    Usuario pUsuario=(Usuario)request.getSession().getAttribute("p_usuario");
	    
	    String msg="";
	    if(idCliente>0){
	    	Integer cantidad=servicio.validaNroDocumento(nrodocumento,idCliente);
	    	if(cantidad<=0){
	    		res=servicio.actualizaCliente(idCliente,idTipoCliente,idTipoDocumento,denominacion,nrodocumento,telefono,direccion,pUsuario);
	    	}else{
	    		msg="Existe un registro de cliente con el nmero "+nrodocumento+", porfavor verificar !";
	    	}
	    }else{
	    	Integer cantidad=servicio.validaNroDocumento(nrodocumento);
	    	if(cantidad<=0){
	    		res=servicio.registraCliente(idTipoCliente,idTipoDocumento,denominacion,nrodocumento,telefono,direccion,pUsuario);
	    	}else{
	    		msg="Existe un registro de cliente con el nmero "+nrodocumento+", porfavor verificar !";
	    	}
	    }
	    List lista=servicio.listaClientes();	
	    
		ModelAndView mv = new ModelAndView("mante-cliente-tabla");
		mv.addObject("lista",lista);
		mv.addObject("msg",msg);
		return mv;
   }
   
   @RequestMapping(path={"/eliminar-cliente"},method=RequestMethod.GET)
   public ModelAndView eliminarServicio(Integer idCliente,Model model,HttpServletRequest request) {
	    Integer res=Constante.ID_INICIAL; 
	    ClienteBo servicio=new ClienteBo();
	    Usuario pUsuario=(Usuario)request.getSession().getAttribute("p_usuario");
	    if(idCliente>0){
	    	res=servicio.eliminarCliente(idCliente,pUsuario);
	    }
	    
	    List lista=new LinkedList<Cliente>();
	    if(res>0){
	    	lista=servicio.listaClientes();	
	    }
		ModelAndView mv = new ModelAndView("mante-cliente-tabla");
		mv.addObject("lista",lista);
		return mv;
   }
   
   @RequestMapping(path={"/generar-dbf-concar"},method=RequestMethod.GET)
   public ModelAndView generarDbfConcar(String fechaComprobante,Model model,HttpServletRequest request) throws Exception {
	    ClienteBo servicio=new ClienteBo();
	    try{
		    CreateDBFConcar concar=new CreateDBFConcar();
		    concar.create(fechaComprobante);
	    }catch(Exception e){
	    	throw e;
	    }
	    
	    List<DbfGeneracion> lGeneraDbf=servicio.listaDbfGeneracion();
		ModelAndView mv = new ModelAndView("proceso-dbf-concar-tabla");
		mv.addObject("lista",lGeneraDbf);
		return mv;
   }
   
   
   @RequestMapping(path={"/lista-dbf-concar"},method=RequestMethod.GET)
   public ModelAndView listaDbfConcar(Model model,HttpServletRequest request) {
	    ClienteBo servicio=new ClienteBo();
	    List lDbfGeneracion=servicio.listaDbfGeneracion();
	    
		ModelAndView mv = new ModelAndView("proceso-dbf-concar-tabla");
		mv.addObject("lista",lDbfGeneracion);
		return mv;
   }
   
    @RequestMapping(value="/valida-dni-cliente", method=RequestMethod.GET)
	@ResponseBody
	public Value validaDniCliente(String dni,Model model,HttpServletRequest request) {
	   Usuario pUsuario=(Usuario)request.getSession().getAttribute("p_usuario");
	   Value obj=null;
	   if(pUsuario!=null&&pUsuario.getUsuarioId()>0){
		    ClienteBo servicio=new ClienteBo();
		    Integer cantidad=servicio.validaNroDocumento(dni);
		    if(cantidad>0){
		    	obj=new Value();
		    	obj.setDenominacion("Existe un registro de cliente con el nmero DNI "+dni+", porfavor verificar !");
	    	}
	   }
	   return obj;
	}
    
    @RequestMapping(value="/valida-ruc-cliente", method=RequestMethod.GET)
	@ResponseBody
	public Value validaRucCliente(String ruc,Model model,HttpServletRequest request) {
	   Usuario pUsuario=(Usuario)request.getSession().getAttribute("p_usuario");
	   Value obj=null;
	   if(pUsuario!=null&&pUsuario.getUsuarioId()>0){
		    ClienteBo servicio=new ClienteBo();
		    Integer cantidad=servicio.validaNroDocumento(ruc);
		    if(cantidad>0){
		    	obj=new Value();
		    	obj.setDenominacion("Existe un registro de cliente con el nmero RUC "+ruc+", porfavor verificar !");
	    	}
	   }
	   return obj;
	}
    
   
}




